@@ -62,19 +62,6 @@ extern "C" {
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#if !defined(FALSE)
-#define FALSE 0
-#endif
-#if !defined(TRUE)
-#define TRUE !FALSE
-#endif
-#if !defined(NULL)
-#define NULL (void *)0
-#endif
-#if !defined(NUL)
-#define NUL '\0'
-#endif
-
 /*
 **  ____ Private Part of the API ___________________________
 */
@@ -100,8 +87,29 @@ extern int flock(int fd, int operation);
 extern char *strerror (int err);
 #endif
 
-#if !defined(offsetof)
-#define offsetof(type,member) ((size_t)(&((type *)0)->member))
+#if !defined(FALSE)
+#define FALSE 0
+#endif
+#if !defined(TRUE)
+#define TRUE !FALSE
+#endif
+#if !defined(NULL)
+#define NULL (void *)0
+#endif
+#if !defined(NUL)
+#define NUL '\0'
+#endif
+#if !defined(min_of)
+#define min_of(a,b) ((a) < (b) ? (a) : (b))
+#endif
+#if !defined(max_of)
+#define max_of(a,b) ((a) > (b) ? (a) : (b))
+#endif
+#if !defined(absof)
+#define abs_of(a) ((a) < 0 ? -(a) : (a))
+#endif
+#if !defined(offset_of)
+#define offset_of(type,member) ((size_t)(&((type *)0)->member))
 #endif
 
 #if !defined(HAVE_MEMCPY) 
